@@ -1,5 +1,4 @@
 import sys
-import bio_assembly_refinement
 import openpyxl
 import pyfastaq
 import pymummer
@@ -8,12 +7,12 @@ from circlator import external_progs, __version__
 from circlator import __version__ as circlator_version
 
 
-def get_all_versions(filehandle, raise_error=True):
+def get_all_versions(filehandle, raise_error=True, debug=False):
     if filehandle is not None:
         print('Circlator version:', circlator_version, file=filehandle)
         print('\nExternal dependencies:', file=filehandle)
 
-    external_progs.check_all_progs(verbose=False, raise_error=raise_error, filehandle=filehandle)
+    external_progs.check_all_progs(verbose=False, raise_error=raise_error, filehandle=filehandle, debug=debug)
 
     if filehandle is not None:
         print('\nPython version:', file=filehandle)
@@ -22,7 +21,7 @@ def get_all_versions(filehandle, raise_error=True):
 
     found_bad_module = False
 
-    for module in ['bio_assembly_refinement', 'openpyxl', 'pyfastaq', 'pymummer', 'pysam']:
+    for module in ['openpyxl', 'pyfastaq', 'pymummer', 'pysam']:
         try:
             version = eval(module + '.__version__')
             path = eval(module + '.__file__')
